/* ConditionalInstruction.java
 * Created 9/13/96 by Mark Gritter 
 */

package EDU.gac.mgritter.SLIME;

import java.lang.*;

/**
 * A conditional jump instruction has a register and a destination address.
 */
public class ConditionalInstruction extends JumpInstruction {
  protected int reg;

  private int op;
  public static final int JEQZ = 2;
  
  /**
   * Create a new instruction.
   *
   * @param operation Should be JEQZ, jump on equal to zero
   * @param register Register for conditional
   * @param address Destination regsiter for jump.
   */
  public ConditionalInstruction(int operation, int register, int address) {
    super(J, address);
    op = operation;
    reg = register;
  }
  
  public int getRegister() { return reg; }

  public String mnemonic() {
    switch (op) {
    case JEQZ: return "jeqz";
    }
    return "CND?";
  }

  public String arguments() {
    return formatReg(reg) + ", [" + formatReg(addr) + "]";
  }

  public void perform(MachineState state) {
    int val = state.getRegister(reg);
    switch (op) {
    case JEQZ:
      if (val == 0) super.perform(state);
      break;
    }
  }
}
