/* IOInstruction.java
 * Created 9/16/96 by Mark Gritter 
 */

package EDU.gac.mgritter.SLIME;

import java.lang.*;

/**
 * An instruction for reading or writing words.
 */
class IOInstruction extends Instruction {
  protected int reg;
  protected int io;

  private int op;
  public static final int READ = 1, WRITE = 2;
  
  /**
   * Create a new instruction.
   *
   * @param operation One of READ or WRITE.
   * @param register Destination/source register.
   * @param port I/O port (0 = console)
   */
  public IOInstruction(int operation, int register, int port) {
    op = operation;
    reg = register;
    io = port;
  }

  public int getReg() { return reg; }
  public int getPort() { return io; }

  public String mnemonic() {
    switch (op) {
    case READ: return "read";
    case WRITE: return "write";
    }
    return "IO?";
  }
 
  public String arguments() {
    return formatReg(reg); // + ", " + formatWord(io);
  }

  public void perform(MachineState state) {
    switch (op) {
    case READ:
      if (io == 0) {
	state.setRegister(reg, state.readConsole());
      }
      break;
    case WRITE:
      if (io == 0) {
	state.writeConsole(state.getRegister(reg));
      }
      break;
    }
  }
}

 




