/* ImmediateInstruction.java
 * Created 9/13/96 by Mark Gritter 
 */

package EDU.gac.mgritter.SLIME;

import java.lang.*;

/**
 * An immediate operation has two operands, a register and a word.
 */
public class ImmediateInstruction extends Instruction {
  protected int reg;
  protected int word;

  private int op;
  public static final int LI = 1;
  
  /**
   * Create a new instruction. 
   *
   * @param operation Only has LI defined for now.
   * @param register Destination register.
   * @param immword Immediate word.
   */
  public ImmediateInstruction(int operation, int register, int immword) {
    op = operation;
    reg = register;
    word = immword;
  }

  public int getReg() { return reg; }
  public int getWord() { return word; }

  public String mnemonic() {
    switch (op) {
    case LI: return "li";
    }
    return "IMM?";
  }

  public String arguments() {
    return formatReg(reg) + ", " + 
           formatWord(word);
  }

  public void perform(MachineState state) {
    switch (op) {
    case LI: 
      state.setRegister(reg, word);
      break;
    }
  }
}
