/* Indicator.java
 *
 * Version 0.2 - Created 9/19/96 by Mark Gritter 
 *
 * Version 0.3 - Modified 7/28/97 by Mark Gritter
 *   Now displays text messages instead of graphics.
 *   Added a function for setting the text color.
 */

package EDU.gac.mgritter.SLIME;

import java.lang.*;
import java.awt.*;
import java.io.*;

/**
 * An Indicator is a sort of graphical checkbox.  It has two 
 * states, but responds to mouse events like a button.
 */

public class Indicator extends Panel {
  private String act;
  private String[] dispstr;
  private Font courier;
  private int state;
  private Color[] color;
  private Dimension pSize;
  private Dimension[] tSize;
  private int tDescent;

  /**
   * @param s0 String to display for state 0.
   * @param s1 String to display for state 1.
   * @param actionstring Object sent to "action" method on mouse click.
   */
  public Indicator(String actionstring, String s0, String s1) {
    act = actionstring;

    dispstr = new String[2];
    dispstr[0] = s0;
    dispstr[1] = s1;
    courier = new Font("Courier", Font.PLAIN, 12);
    if (courier == null) {
      System.err.println("Couldn't locate font Courier-plain-12");
      courier = new Font ("Dialog", Font.PLAIN, 10);
      if (courier == null) System.exit(1);
    }
    color = new Color[2];
    color[0] = new Color(0, 255, 0);  // green
    color[1] = new Color(255, 0, 0);  // red
    setBackground(Color.black);
    
    Toolkit tk = Toolkit.getDefaultToolkit();
    FontMetrics fm = tk.getFontMetrics(courier);
    int w0 = fm.stringWidth(s0), w1 = fm.stringWidth(s1);
    int width = w0 > w1 ? w0 : w1, height = fm.getAscent() + fm.getDescent();
    tDescent = fm.getDescent();
    tSize = new Dimension[2];
    tSize[0] = new Dimension(w0, height);
    tSize[1] = new Dimension(w1, height);
    pSize = new Dimension((width * 12) / 10 + 1, (height * 12) / 10 + 1);
  }
 
  public Dimension preferredSize() {
    return pSize;
  }

  public void paint(Graphics g) {
    g.setFont(courier);
    g.setColor(color[state]);
    Dimension s = size();
    int y = (s.height + tSize[state].height) / 2 - tDescent;
    int x = (s.width - tSize[state].width) / 2;
    g.drawString(dispstr[state], x, y);
  }

  public void setState(boolean s) {
    if (s) state = 1; else state = 0;
    repaint();
  }

  public boolean state() {
    if (state == 0) return false;
    else return true;
  }

  public boolean mouseDown(Event evt, int x, int y) {
    postEvent(new Event(this, Event.ACTION_EVENT, act));
    return true;
  }

  public void setColor(boolean s, Color c) {
    int i = s ? 1 : 0;
    color[i] = c;
  }
}






