/* Instruction.java
 * Created 9/12/96 by Mark Gritter
 *
 * Version 0.3 - Modified 7/28/97 by Mark Gritter
 *   Added "original_label" for storing the instruction's label.
 *   Modified toString to give a nicer display.
 */

package EDU.gac.mgritter.SLIME;

import java.lang.*;
import java.io.*;

/**
 * Base class for all instructions.
 */
abstract public class Instruction {
  protected String original;
  protected String original_label;

  /**
   * Number of chars allocated before start of instruction mnemonic.
   */
  public static int labelLength = 15;

  /**
   * Number of chars allocated before start of comment text.
   */
  public static int instructionLength = 40;

  /**
   * Set the text to display with this instruction. 
   */
  public void setText(String o) {
    original = o;
  }

  /**
   * Set the label for this instruction. 
   */
  public void setLabel(String l) {
    original_label = l;
  }

  /**
   * Perform this instruction on the given machine state.
   */
  public abstract void perform(MachineState state);

  /**
   * Return the arguments for this instruction.
   */
  public abstract String arguments();

  /**
   * Return the mnemonic for this instruction.
   */
  public abstract String mnemonic();
  
  /**
   * The text for this instruction, formatted nicely for 
   * a non-proportional font.
   */
  public String toString() {
    String ret = mnemonic() + " " + arguments();
    String l = "";
    if (original_label != null) l = original_label + ": ";
    while (l.length() < labelLength) l += " ";
    ret = l + ret;
    if (original != null) {
      while (ret.length() < instructionLength) ret += " ";
      ret = ret + "# " + original;
    }
    return ret;
  }

  /**
   * Format a register number for displaying.
   */
  public static String formatReg(int regnum) {
    if (regnum < 10) return "0" + regnum;
    return String.valueOf(regnum);
  }

  /**
   * Format a word for displaying in instruction text.
   */
  public static String formatWord(int word) {
    return "" + word;
  }

  /**
   * Format an address for displaying.
   */
  public static String formatAddress(int address) {
    return String.valueOf(address);
  }
}







