/* MemoryInstruction.java
 * Created 9/12/96 by Mark Gritter 
 */

package EDU.gac.mgritter.SLIME;

import java.lang.*;

/**
 * An instruction for accessing memory.  Two operands: register for word 
 * and a register for the memory address.
 */
class MemoryInstruction extends Instruction {
  protected int reg;
  protected int addr;

  private int op;
  public static final int LD = 1, ST = 2;
  
  /**
   * Create a new instruction.
   *
   * @param operation One of LD or ST.
   * @param register Destination/source register.
   * @param address Register holding data memory address.
   */
  public MemoryInstruction(int operation, int register, int address) {
    op = operation;
    reg = register;
    addr = address;
  }

  public int getReg() { return reg; }
  public int getAddress() { return addr; }

  public String mnemonic() {
    switch (op) {
    case LD: return "ld";
    case ST: return "st";
    }
    return "MEM?";
  }
 
  public String arguments() {
    return formatReg(reg) + ", [" + formatReg(addr) + "]";
  }

  public void perform(MachineState state) {
    int address = state.getRegister(addr);
    if (address < 0) {
      state.raiseException(MachineState.EX_NODATA);
      return;
    }
    switch (op) {
    case LD: 
      state.setRegister(reg, state.getWord(address));
      break;
    case ST:
      state.setWord(address, state.getRegister(reg));
      break;
    }
  }
}

 

