/* UserInterface.java
 *
 * Version 0.1 - Created 9/12/96 by Mark Gritter 
 *
 * Version 0.2 - Modified 9/19/96 by Mark Gritter 
 *   Added countChanged for instruction counter.
 *
 * Version 0.3 - Modified 7/28/97 by Mark Gritter 
 *   Added dispose method so that applets will be able to exit correctly.
 */

package EDU.gac.mgritter.SLIME;

import java.lang.*;

/**
 * Interface for user interaction with SLIME.  Provides functions for 
 * showing registers, memory, data, registering exceptions, etc.
 */

public interface UserInterface {

  /**
   * Notification that item in data memory has changed.
   */
  public void dataChanged(int address, int newvalue);

  /**
   * Notification that item in instruction memory has changed.
   */
  public void instructionChanged(int address, Instruction newinst);

  /**
   * Notification that program counter has changed.
   */
  public void PCChanged(int newpc);

  /**
   * Notification that register has changed.
   */
  public void registerChanged(int reg, int newvalue);

  /**
   * Notification that exception has occured or cleared.
   */
  public void exceptionRaised(String message);

  /**
   * Read integer from console.
   */
  public int readConsole();
  
  /**
   * Write integer to console.
   */
  public void writeConsole(int n);
  
  /**
   * Show parsing errors.
   */
  public void showErrors(String[] errors);

  /**
   * Show instruction count.
   */
  public void countChanged(int c);

  /**
   * Shut down windows, etc.
   */
  public void dispose();
}





